@@ -246,6 +246,12 @@ var:
 			s->sysFlush(tsid);
 		else if(!stricmp(cmd, "wait"))
 			s->sysWait(tsid, tok);
+		else if(!stricmp(cmd, "tone"))
+			s->sysTone(tsid, tok);
+		else if(!stricmp(cmd, "stone"))
+			s->sysSTone(tsid, tok);
+		else if(!stricmp(cmd, "dtone"))
+			s->sysDTone(tsid, tok);
                 else if(!stricmp(cmd, "args1"))
                 {
                         event.id = ARGS_LIBEXEC;
@@ -282,9 +288,15 @@ void BayonneSysexec::execute(unsigned ts, const char *cmd)
 	int pid, fd;
 	char path[256];
 	char fname[32];
-	char buf[65];
-	char *args[2];
+	char buf[256];
+	char *args[12];
 	unsigned count = 3;
+	bool jar = false;
+	bool java = false;
+	char *ext, *dp;
+	unsigned diff;
+	int argc;
+	int rts = -1;	
 
 	if(!strnicmp(cmd, "exec::", 6))
 		snprintf(path, sizeof(path), "%s/%s", syspath, cmd + 6);
@@ -292,9 +304,64 @@ void BayonneSysexec::execute(unsigned ts, const char *cmd)
 		snprintf(path, sizeof(path), "%s/%s", libpath, cmd);
 	snprintf(fname, sizeof(fname), "%s/.libexec-%d", path_tmp, ts);
 
+	ext = strrchr(path, '.');
+	dp = strrchr(path, '/');
+	if(!ext)
+		goto normal;
+
+	diff = dp - path;
+
+        if(ext && !stricmp(ext, ".class"))
+        {
+		*ext = 0;
+		args[0] = JAVA_PROGRAM;
+		snprintf(buf, sizeof(buf), "-Dbayonne.home=%s",
+			Process::getEnv("SERVER_PREFIX"));
+		args[1] = newString(buf);
+		snprintf(buf, sizeof(buf), "-Dbayonne.ramfs=%s",
+			Process::getEnv("SERVER_TMPFS"));
+		args[2] = newString(buf);
+		snprintf(buf, sizeof(buf), "-Dbayonne.tmpfs=%s",
+			Process::getEnv("SERVER_TMP"));
+		args[3] = newString(buf);
+                snprintf(buf, sizeof(buf), "-Dbayonne.tsid=%s", slot[ts].tsid);
+                args[4] = newString(buf);
+                args[5] = newString(++dp);
+                args[6] = NULL;
+		argc = 6;
+		setString(path, sizeof(path), JAVA_PROGRAM);
+                goto launch;       
+        }  
+
+	if(ext && !stricmp(ext, ".jar"))
+	{
+		args[0] = JAVA_PROGRAM;
+                snprintf(buf, sizeof(buf), "-Dbayonne.home=%s",
+                        Process::getEnv("SERVER_PREFIX"));
+                args[1] = newString(buf);
+                snprintf(buf, sizeof(buf), "-Dbayonne.ramfs=%s", 
+                        Process::getEnv("SERVER_TMPFS"));       
+                args[2] = newString(buf);      
+                snprintf(buf, sizeof(buf), "-Dbayonne.tmpfs=%s",
+                        Process::getEnv("SERVER_TMP"));
+                args[3] = newString(buf);  
+		snprintf(buf, sizeof(buf), "-Dbayonne.tsid=%s", slot[ts].tsid);
+		args[4] = newString(buf);
+		args[5] = "-jar";
+		args[6] = newString(++dp);
+		args[7] = NULL;
+		argc = 7;
+		setString(path, sizeof(path), JAVA_PROGRAM);
+		goto launch;
+	}
+
+
+normal:
 	args[0] = path;
 	args[1] = NULL;
+	argc = 1;
 
+launch:
 	pid = fork();
 	if(pid)
 	{
@@ -325,7 +392,7 @@ void BayonneSysexec::execute(unsigned ts, const char *cmd)
 	write(1, buf, strlen(buf));
 
 	execv(path, args);
-	::exit(-1);		
+	::exit(rts);		
 }
 
 void BayonneSysexec::readline(char *buf, unsigned max)
@@ -421,6 +488,12 @@ void BayonneSysexec::allocate(const char *libexec, size_t bs, int pri, const cha
 
 	nice(pri);
 
+	if(!stricmp(syspath, modpath))
+		snprintf(path, sizeof(path), "%s:%s/bayonne.jar", syspath, LIBDIR_FILES);
+	else
+		snprintf(path, sizeof(path), "%s:%s/bayonne.jar:%s/bayonne.jar", syspath, modpath, LIBDIR_FILES); 
+	Process::setEnv("CLASSPATH", path, true);
+
 	chdir(Process::getEnv("SERVER_PREFIX"));
 	getcwd(path, sizeof(path));
 	Process::setEnv("SERVER_PREFIX", path, true);	
