@@ -53,6 +53,8 @@ bool BayonneSession::stateLibexec(Event *event)
 	case RECORD_LIBEXEC:
 		setState(STATE_RECORD);
 		return true;				
+	case TONE_LIBEXEC:
+		setState(STATE_TONE);
 	case WAIT_LIBEXEC:
 		setState(STATE_WAITKEY);
 		return true;
