@@ -46,6 +46,9 @@ sub new {
 	# version of our interface
 	$self->{version} = "4.0";
 
+	# audio level of tones...
+	$self->{level} = 0;
+
 	$self->{tsession} = $ENV{'PORT_TSESSION'} if $ENV{'PORT_TSESSION'};
 	
 	if(!$self->{tsession}) {
@@ -251,7 +254,58 @@ sub erase($$) {
 	self->{result} = 0;
 	return 0;
 }
-	
+
+# play audio tone
+
+sub tone {
+	my $self = shift;
+	my $tone = shift;
+	my $duration = shift;
+	my $level = shift;
+
+	if(!$duration) {
+		$duration = 0;
+	}
+
+	if(!$level) {
+		$level = $self->{level}; 	
+	}
+	return $self->command("tone $tone $duration $level");
+}
+
+sub single_tone {
+	my $self = shift;
+	my $tone = shift;
+	my $duration = shift;
+	my $level = shift;
+
+	if(!$duration) {
+		$duration = 0;
+	}
+
+	if(!$level) {
+		$level = $self->{level}; 	
+	}
+	return $self->command("stone $tone $duration $level");
+}
+
+sub dual_tone {
+	my $self = shift;
+	my $tone1 = shift;
+	my $tone2 = shift;
+	my $duration = shift;
+	my $level = shift;
+
+	if(!$duration) {
+		$duration = 0;
+	}
+
+	if(!$level) {
+		$level = $self->{level}; 	
+	}
+	return $self->command("dtone $tone1 $tone2 $duration $level");
+}
+
 # replay audio
 
 sub replay {
@@ -320,6 +374,11 @@ sub voice {
 	$self->{voice} = $voice;
 }
 
+sub level($$) {
+	my($self, $level) = @_;
+	$self->{level} = $level;
+}
+
 # process input line
 
 sub input($$$) {
