@@ -19,6 +19,7 @@ class Libexec:
 	exitcode = 0
 	resultcode = 0
 	reply = 0
+	level = 0;
 	position = '00:00:00.000'
 	version = '4.0'
 	voice = ''
@@ -168,11 +169,11 @@ class Libexec:
 		return
 		
 	def command(self, text):
+		self.resultcode = 255
+		self.query = ""
 		if self.tsession == "" or not self.tsession or self.exitcode != 0:
 			return 255
 		num = 0
-		self.resultcode = 255
-		self.query = ""
 		sys.stdout.write("%s %s\n" % (self.tsession, text))
 		sys.stdout.flush()
 		while self.exitcode == 0:
@@ -235,7 +236,7 @@ class Libexec:
 			return 254
 		return self.command("RECORD %s %d %d %s" % (file, total, silence, offset))
 
-	def move(self, file1, file2):
+	def moveFile(self, file1, file2):
 		file1 = self.pathname(file1)
 		file2 = self.pathname(file2)
 		if not file1 or file1 == "" or not file2 or file2 == "":
@@ -245,7 +246,7 @@ class Libexec:
 		self.resultcode = 0
 		return 0
 
-	def erase(self, file):
+	def eraseFile(self, file):
 		file = self.pathname(file)
 		if not file or file == "":
 			self.resultcode = 254
@@ -258,10 +259,14 @@ class Libexec:
 		self.voice = voice
 		return true
 
-	def clear(self):
+	def setLevel(self, level):
+		self.level = level
+		return
+
+	def clearInput(self):
 		return self.command("FLUSH")
 
-	def inkey(self, timeout):
+	def readKey(self, timeout):
 		if self.tsession == "" or not self.tsession or self.exitcode != 0:
 			return ""
 		self.digits = ""
@@ -269,15 +274,15 @@ class Libexec:
 			return ""
 		return self.digits
 
-	def input(self, count, timeout):
+	def readInput(self, count, timeout):
 		if self.tsession == "" or not self.tsession or self.exitcode != 0:
 			return ""
 		self.digits = ""
-		if self.command("READ %d %d" % (count, timeout)) != 0:
+		if self.command("READ %d %d" % (timeout, count)) != 0:
 			return ""
 		return self.digits
 
-	def wait(self, timeout):
+	def waitInput(self, timeout):
 		if self.tsession == "" or not self.tsession or self.exitcode != 0:
 			return false
 		self.digits = ""
@@ -290,6 +295,15 @@ class Libexec:
 	def result(self, text):
 		return self.command("RESULT %s" % text)
 
+	def playTone(self, tone, duration):
+		return self.command("TONE %s %d %d" % (tone, duration, self.level))
+
+	def playSingleTone(self, tone, duration):
+		return self.command("STONE %d %d %d" % (tone, duration, self.level))
+
+	def playDualTone(self, tone1, tone2, duration):
+		return self.command("DTONE %d %d %d %d" % (tone1, tone2, duration, self.level))
+
 	def speak(self, text):
 		if self.voice == "" or not self.voice:
 			voice = "PROMPT"
@@ -297,16 +311,16 @@ class Libexec:
 			voice = self.voice
 		return self.command("%s %s" % (voice, text))
 
-	def size(self, sym, count):
+	def sizeSymbol(self, sym, count):
 		return self.command("NEW %s %d" % (sym, count))
 
-	def set(self, sym, value):
+	def setSymbol(self, sym, value):
 		return self.command("SET %s %s" % (sym, value))
 
-	def add(self, sym, value):
+	def addSymbol(self, sym, value):
 		return self.command("ADD %s %s" % (sym, value))
 
-	def get(self, sym):
+	def getSymbol(self, sym):
 		if self.tsession == "" or not self.tsession or self.exitcode != 0:
 			return ""
 		self.query = ""
